#!/bin/bash

##################################################################################
#  Copyright notice
#
#  (c) 2003-2010 Renzo Lauper (renzo@churchtool.org)
#  All rights reserved
#
#  This script is part of the kOOL project. The kOOL project is
#  free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  The GNU General Public License can be found at
#  http://www.gnu.org/copyleft/gpl.html.
#  A copy is found in the textfile GPL.txt and important notices to the license
#  from the author is found in LICENSE.txt distributed with these scripts.
#
#  kOOL is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  This copyright notice MUST APPEAR in all copies of the script!
##################################################################################


# #############################
# KOOL MULTIHOST SETUP SCRIPT #
# #############################


# Settings
# --------
# adapt them to meet your server settings
#

# The path to the kOOL source directory to be used
kOOL_LIB_PATH="/var/lib/kOOL/lib"

# The group the apache webserver runs as
WWW_GROUP="www-data"




# -------------------------------------
# End of configurations section
# Don't change anything below this line
# -------------------------------------


# Check for bash as calling shell
#if [[ ! $SHELL =~ "bash" ]] ; then
#	echo >&2
#	echo "ERROR: It looks like another shell than bash is running this script: '$SHELL'" >&2
#	echo "       Call it again using bash." >&2
#	echo >&2
#	exit 1;
#fi;


# Check for correct directory by locating kOOL_setup.sh in current directory
if [[ ! -e ./kOOL_setup.sh ]]; then
	echo >&2
	echo "ERROR: Can not find kOOL_setup.sh in current directory. Can not continue." >&2
	echo "       Make sure you run this script from inside your kOOL web directory (e.g. /var/www/kOOL_demo)" >&2
	echo >&2
	exit 1;
fi;


#
# Start installation
#
echo " *** kOOL Setup Script *** "
echo


# symlink kOOL_lib
if [[ ! -L ./kOOL_lib ]]; then rm -f kOOL_lib && ln -s $kOOL_LIB_PATH ./kOOL_lib ; fi


# General files
echo -n "general files, ";
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ./kOOL_lib/index.php ./index.php ; fi
if [[ ! -L ./menu.php ]]; then rm -f menu.php && ln -s ./kOOL_lib/menu.php ./menu.php ; fi
if [[ ! -L ./download.php ]]; then rm -f download.php && ln -s ./kOOL_lib/download.php ./download.php ; fi
if [[ ! -L ./kOOL.css ]]; then rm -f kOOL.css && ln -s ./kOOL_lib/kOOL.css ./kOOL.css ; fi
if [[ ! -L ./ie6.css ]]; then rm -f ie6.css && ln -s ./kOOL_lib/ie6.css ./ie6.css ; fi
if [[ ! -L ./ie7.css ]]; then rm -f ie7.css && ln -s ./kOOL_lib/ie7.css ./ie7.css ; fi
if [[ ! -L ./get.php ]]; then rm -f get.php && ln -s ./kOOL_lib/get.php ./get.php ; fi


# Images
echo -n "images, ";
if [[ ! -L ./images ]]; then rm -rf images && ln -s ./kOOL_lib/images ./images ; fi
if [[ ! -d ./my_images ]]; then mkdir my_images ; fi
chmod g+w my_images
cd my_images
# Don't override any files in my_images
for datei in `ls ../kOOL_lib/install/default/my_images/*.gif` ; do
	if [[ ! -e `basename $datei` ]]; then
		cp $datei . ;
	fi
done
touch index.html


# Include directory
echo -n "inc, "
cd ..
if [[ ! -d ./inc ]]; then mkdir inc ; fi
cd inc
files='ajax.php ColorPicker2.js error_handling.inc front_modules.inc kOOL.js selectmenu.js ko.inc kota.inc session.inc js-sessiontimeout.inc smarty.inc mime_mail.inc submenu_actions.inc submenu.inc Clickatell.php abuse.inc hooks.inc lang.inc class.kOOL_listview.php class.mcrypt.php graph_bar.php graph_piechart.php fullcalendar.css js-fullcalendar.min.js class.excelwriter.php'
for datei in $files ; do
	if [[ ! -L ./$datei ]]; then rm -f $datei && ln -s ../kOOL_lib/inc/$datei ./$datei ; fi
done
if [[ ! -L ./calendar ]]; then rm -rf calendar && ln -s ../kOOL_lib/inc/calendar ./calendar ; fi
if [[ ! -L ./jquery ]]; then rm -rf jquery && ln -s ../kOOL_lib/inc/jquery ./jquery ; fi
# Delete old links
if [[ -L ./js-kOOL.inc ]]; then rm -f js-kOOL.inc ; fi
if [[ -L ./js-ajax.inc ]]; then rm -f js-ajax.inc ; fi
if [[ -L ./js-popup.inc ]]; then rm -f js-popup.inc ; fi
if [[ -L ./js-selectmenu.inc ]]; then rm -f js-selectmenu.inc ; fi
if [[ -L ./popup.js ]]; then rm -f popup.js ; fi
if [[ -L ./ajax.js ]]; then rm -f ajax.js ; fi
if [[ -L ./tooltip.js ]]; then rm -f tooltip.js ; fi
if [[ -L ./auth.inc ]]; then rm -f auth.inc ; fi


# The files for FreePDF
echo -n "FreePDF, "
cd ..
if [[ ! -d ./fpdf ]]; then mkdir fpdf ; fi
cd fpdf
if [[ ! -L ./fpdf.php ]]; then rm -f fpdf.php && ln -s ../kOOL_lib/fpdf/fpdf.php ./fpdf.php ; fi
if [[ ! -L ./pdf_leute.php ]]; then rm -f pdf_leute.php && ln -s ../kOOL_lib/fpdf/pdf_leute.php ./pdf_leute.php ; fi
if [[ ! -L ./mc_table.php ]]; then rm -f mc_table.php && ln -s ../kOOL_lib/fpdf/mc_table.php ./mc_table.php ; fi
if [[ ! -d ./schriften ]]; then mkdir schriften ; fi
cd schriften
for datei in `ls ../../kOOL_lib/install/default/fpdf/schriften/*` ; do
	if [[ ! -e `basename $datei` ]]; then
		cp $datei . ;
	fi
done
cd ..
if [[ ! -d ./images ]]; then mkdir images ; fi
if [[ ! -e ./images/logo.png ]]; then cp ../kOOL_lib/install/default/fpdf/images/logo.png ./images ; fi
if [[ ! -e ./images/pdf-point.png ]]; then cp ../kOOL_lib/install/default/fpdf/images/pdf-point.png ./images ; fi


# Default files
echo -n "defaults, "
cd ..
if [[ ! -e ./footer.php ]]; then cp ./kOOL_lib/install/default/footer.php . ; fi
if [[ ! -e ./header.php ]]; then cp ./kOOL_lib/install/default/header.php . ; fi
if [[ ! -e ./ko.css ]]; then cp ./kOOL_lib/install/default/ko.css . ; fi
if [[ ! -d ./config ]]; then mkdir config ; fi
cd config
if [[ ! -e ./ko-config.php ]]; then cp ../kOOL_lib/install/default/config/ko-config.php . ; fi
if [[ ! -e ./leute_formular.inc ]]; then cp ../kOOL_lib/install/default/config/leute_formular.inc . ; fi
chmod o-rx ./ko-config.php
chmod g+w ./ko-config.php
chmod g+w ./leute_formular.inc
cd ..


# Installation
echo -n "install, "
if [[ ! -d ./install ]]; then mkdir install ; fi
chmod g+w install
cd install
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/install/index.php ./index.php ; fi
if [[ ! -L ./kOOL_db.sql ]]; then rm -f kOOL_db.sql && ln -s ../kOOL_lib/install/kOOL_db.sql ./kOOL_db.sql ; fi
if [[ ! -L ./db_de.sql ]]; then rm -f db_de.sql && ln -s ../kOOL_lib/install/db_de.sql ./db_de.sql ; fi
cd ..


# Module: admin
echo -n "admin, "
if [[ ! -d ./admin ]]; then mkdir admin ; fi
cd admin
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/admin/index.php ./index.php ; fi
if [[ ! -d ./inc ]]; then mkdir inc ; fi
if [[ ! -L ./inc/admin.inc ]]; then rm -f inc/admin.inc && ln -s ../../kOOL_lib/admin/inc/admin.inc ./inc/admin.inc ; fi
if [[ ! -L ./inc/ajax.php ]]; then rm -f inc/ajax.php && ln -s ../../kOOL_lib/admin/inc/ajax.php ./inc/ajax.php ; fi
if [[ -L ./inc/js-admin.inc ]]; then rm -f inc/js-admin.inc ; fi


# Module: events
echo -n "events, "
cd ..
if [[ ! -d ./daten ]]; then mkdir daten ; fi
cd daten
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/daten/index.php ./index.php ; fi
if [[ ! -d ./inc ]]; then mkdir inc ; fi
if [[ ! -L ./inc/daten.inc ]]; then rm -f inc/daten.inc && ln -s ../../kOOL_lib/daten/inc/daten.inc ./inc/daten.inc ; fi
if [[ ! -L ./inc/js-daten.inc ]]; then rm -f inc/js-daten.inc && ln -s ../../kOOL_lib/daten/inc/js-daten.inc ./inc/js-daten.inc ; fi
if [[ ! -L ./inc/js-seleventgroup.inc ]]; then rm -f inc/js-seleventgroup.inc && ln -s ../../kOOL_lib/daten/inc/js-seleventgroup.inc ./inc/js-seleventgroup.inc ; fi
if [[ ! -e ./inc/pdf_daten.inc ]]; then cp ../kOOL_lib/install/default/daten/inc/pdf_daten.inc ./inc/pdf_daten.inc ; fi
if [[ ! -L ./inc/ajax.php ]]; then rm -f inc/ajax.php && ln -s ../../kOOL_lib/daten/inc/ajax.php ./inc/ajax.php ; fi


# Module: addresses
echo -n "addresses, "
cd ..
if [[ ! -d ./leute ]]; then mkdir leute ; fi
cd leute
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/leute/index.php ./index.php ; fi
if [[ ! -d ./inc ]]; then mkdir inc ; fi
if [[ ! -L ./inc/js-leute.inc ]]; then rm -f inc/js-leute.inc && ln -s ../../kOOL_lib/leute/inc/js-leute.inc ./inc/js-leute.inc ; fi
if [[ ! -L ./inc/js-groupmenu.inc ]]; then rm -f inc/js-groupmenu.inc && ln -s ../../kOOL_lib/leute/inc/js-groupmenu.inc ./inc/js-groupmenu.inc ; fi
if [[ ! -L ./inc/leute.inc ]]; then rm -f inc/leute.inc && ln -s ../../kOOL_lib/leute/inc/leute.inc ./inc/leute.inc ; fi
if [[ ! -L ./inc/kg.inc ]]; then rm -f inc/kg.inc && ln -s ../../kOOL_lib/leute/inc/kg.inc ./inc/kg.inc ; fi
if [[ ! -L ./inc/ajax.php ]]; then rm -f inc/ajax.php && ln -s ../../kOOL_lib/leute/inc/ajax.php ./inc/ajax.php ; fi
if [[ ! -L ./inc/vcard.php ]]; then rm -f inc/vcard.php && ln -s ../../kOOL_lib/leute/inc/vcard.php ./inc/vcard.php ; fi


# Module: reservations
echo -n "reservation, "
cd ..
if [[ ! -d ./reservation ]]; then mkdir reservation ; fi
cd reservation
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/reservation/index.php ./index.php ; fi
if [[ ! -d ./inc ]]; then mkdir inc ; fi
if [[ ! -L ./inc/reservation.inc ]]; then rm -f inc/reservation.inc && ln -s ../../kOOL_lib/reservation/inc/reservation.inc ./inc/reservation.inc ; fi
if [[ ! -L ./inc/js-reservation.inc ]]; then rm -f inc/js-reservation.inc && ln -s ../../kOOL_lib/reservation/inc/js-reservation.inc ./inc/js-reservation.inc ; fi
if [[ ! -L ./inc/ajax.php ]]; then rm -f inc/ajax.php && ln -s ../../kOOL_lib/reservation/inc/ajax.php ./inc/ajax.php ; fi


# Module: rota
echo -n "rota, "
cd ..
if [[ ! -d ./dp ]]; then mkdir dp ; fi
cd dp
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/dp/index.php ./index.php ; fi
if [[ ! -d ./inc ]]; then mkdir inc ; fi
if [[ ! -L ./inc/dp.inc ]]; then rm -f inc/dp.inc && ln -s ../../kOOL_lib/dp/inc/dp.inc ./inc/dp.inc ; fi
if [[ ! -L ./inc/ajax.php ]]; then rm -f inc/ajax.php && ln -s ../../kOOL_lib/dp/inc/ajax.php ./inc/ajax.php ; fi
if [[ -L ./inc/js-dp.inc ]]; then rm -f inc/js-dp.inc ; fi


# Module: fileshare
echo -n "fileshare, "
cd ..
if [[ ! -d ./fileshare ]]; then mkdir fileshare ; fi
cd fileshare
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/fileshare/index.php ./index.php ; fi
if [[ ! -d ./inc ]]; then mkdir inc ; fi
if [[ ! -L ./inc/fileshare.inc ]]; then rm -f inc/fileshare.inc && ln -s ../../kOOL_lib/fileshare/inc/fileshare.inc ./inc/fileshare.inc ; fi
if [[ ! -L ./inc/js-fileshare.inc ]]; then rm -f inc/js-fileshare.inc && ln -s ../../kOOL_lib/fileshare/inc/js-fileshare.inc ./inc/js-fileshare.inc ; fi
if [[ ! -L ./inc/ajax.php ]]; then rm -f inc/ajax.php && ln -s ../../kOOL_lib/fileshare/inc/ajax.php ./inc/ajax.php ; fi


# Module: tools
echo -n "tools, "
cd ..
if [[ ! -d ./tools ]]; then mkdir tools ; fi
cd tools
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/tools/index.php ./index.php ; fi
if [[ ! -d ./inc ]]; then mkdir inc ; fi
if [[ ! -L ./inc/tools.inc ]]; then rm -f inc/tools.inc && ln -s ../../kOOL_lib/tools/inc/tools.inc ./inc/tools.inc ; fi


# Module: tapes
echo -n "tapes, "
cd ..
if [[ ! -d ./tapes ]]; then mkdir tapes ; fi
cd tapes
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/tapes/index.php ./index.php ; fi
if [[ ! -d ./inc ]]; then mkdir inc ; fi
if [[ ! -L ./inc/tapes.inc ]]; then rm -f inc/tapes.inc && ln -s ../../kOOL_lib/tapes/inc/tapes.inc ./inc/tapes.inc ; fi
if [[ ! -L ./inc/js-tapes.inc ]]; then rm -f inc/js-tapes.inc && ln -s ../../kOOL_lib/tapes/inc/js-tapes.inc ./inc/js-tapes.inc ; fi
if [[ ! -L ./inc/ajax.php ]]; then rm -f inc/ajax.php && ln -s ../../kOOL_lib/tapes/inc/ajax.php ./inc/ajax.php ; fi



# Module: groups
echo -n "groups, "
cd ..
if [[ ! -d ./groups ]]; then mkdir groups ; fi
cd groups
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/groups/index.php ./index.php ; fi
if [[ ! -d ./inc ]]; then mkdir inc ; fi
if [[ ! -L ./inc/groups.inc ]]; then rm -f inc/groups.inc && ln -s ../../kOOL_lib/groups/inc/groups.inc ./inc/groups.inc ; fi
if [[ ! -L ./inc/js-groups.inc ]]; then rm -f inc/js-groups.inc && ln -s ../../kOOL_lib/groups/inc/js-groups.inc ./inc/js-groups.inc ; fi
if [[ ! -L ./inc/ajax.php ]]; then rm -f inc/ajax.php && ln -s ../../kOOL_lib/groups/inc/ajax.php ./inc/ajax.php ; fi



# Module: donations
echo -n "donations, "
cd ..
if [[ ! -d ./donations ]]; then mkdir donations ; fi
cd donations
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/donations/index.php ./index.php ; fi
if [[ ! -d ./inc ]]; then mkdir inc ; fi
if [[ ! -L ./inc/donations.inc ]]; then rm -f inc/donations.inc && ln -s ../../kOOL_lib/donations/inc/donations.inc ./inc/donations.inc ; fi
if [[ ! -L ./inc/js-donations.inc ]]; then rm -f inc/js-donations.inc && ln -s ../../kOOL_lib/donations/inc/js-donations.inc ./inc/js-donations.inc ; fi
if [[ ! -L ./inc/ajax.php ]]; then rm -f inc/ajax.php && ln -s ../../kOOL_lib/donations/inc/ajax.php ./inc/ajax.php ; fi



# Module: tracking
echo -n "tracking, "
cd ..
if [[ ! -d ./tracking ]]; then mkdir tracking ; fi
cd tracking
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/tracking/index.php ./index.php ; fi
if [[ ! -d ./inc ]]; then mkdir inc ; fi
if [[ ! -L ./inc/tracking.inc ]]; then rm -f inc/tracking.inc && ln -s ../../kOOL_lib/tracking/inc/tracking.inc ./inc/tracking.inc ; fi
if [[ ! -L ./inc/js-tracking.inc ]]; then rm -f inc/js-tracking.inc && ln -s ../../kOOL_lib/tracking/inc/js-tracking.inc ./inc/js-tracking.inc ; fi
if [[ ! -L ./inc/ajax.php ]]; then rm -f inc/ajax.php && ln -s ../../kOOL_lib/tracking/inc/ajax.php ./inc/ajax.php ; fi



# Download folder
echo -n "download, "
cd ..
if [[ ! -d ./download ]]; then mkdir download ; fi
if [[ ! -e ./download/index.php ]]; then cp ./kOOL_lib/install/default/download/index1.php ./download/index.php ; fi
if [[ ! -d ./download/excel ]]; then mkdir download/excel ; fi
if [[ ! -e ./download/excel/index.php ]]; then cp ./kOOL_lib/install/default/download/index2.php ./download/excel/index.php ; fi
if [[ ! -d ./download/pdf ]]; then mkdir download/pdf ; fi
if [[ ! -e ./download/pdf/index.php ]]; then cp ./kOOL_lib/install/default/download/index2.php ./download/pdf/index.php ; fi
if [[ ! -d ./download/dp ]]; then mkdir download/dp ; fi
if [[ ! -e ./download/dp/index.php ]]; then cp ./kOOL_lib/install/default/download/index2.php ./download/dp/index.php ; fi
chgrp $WWW_GROUP download download/excel download/pdf download/dp
chmod g+w download download/excel download/pdf download/dp


# iCal
echo -n "iCal, "
if [[ ! -d ./ical ]]; then mkdir ical ; fi
cd ical
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/ical/index.php ./index.php ; fi
cd ..
if [[ ! -d ./resical ]]; then mkdir resical ; fi
cd resical
if [[ ! -L ./index.php ]]; then rm -f index.php && ln -s ../kOOL_lib/resical/index.php ./index.php ; fi
cd ..


# Webfolders
echo -n "Webfolders, "
if [[ ! -d ./webfolders ]]; then mkdir webfolders ; fi
if [[ ! -d ./.webfolders ]]; then mkdir .webfolders ; fi
chgrp $WWW_GROUP webfolders .webfolders
chmod g+w webfolders .webfolders


# Plugins
echo -n "Plugins, "
if [[ ! -d ./plugins ]]; then mkdir plugins ; fi
cd plugins
for plugin in `ls -d ../kOOL_lib/install/default/plugins/*` ; do
	if [[ ! -d `basename $plugin` ]]; then
		cp -r $plugin . ;
	fi
done
cd ..


# Languages
echo -n "LocalLang, "
if [[ ! -L ./locallang ]]; then rm -rf locallang && ln -s ./kOOL_lib/locallang ./locallang ; fi


# Templates-Directories
echo -n "Templates, "
if [[ ! -L ./templates ]]; then rm -rf templates && ln -s ./kOOL_lib/templates ./templates ; fi
if [[ ! -d ./templates_c ]]; then mkdir templates_c ; fi
chmod g+w templates_c


# LaTeX
echo -n "LaTeX"
if [[ ! -d ./latex ]]; then mkdir latex ; fi
if [[ ! -d ./latex/compile ]]; then mkdir latex/compile ; fi
if [[ ! -d ./latex/images ]]; then mkdir latex/images ; fi
if [[ ! -e ./latex/images/.htaccess ]]; then cp ./kOOL_lib/install/default/latex/images/.htaccess ./latex/images/.htaccess ; fi
if [[ ! -d ./latex/layouts ]]; then mkdir latex/layouts ; fi
cd latex/layouts
if [[ ! -e ./letter_default.lco ]]; then cp ../../kOOL_lib/install/default/latex/layouts/letter_default.lco . ; fi
if [[ ! -e ./mailmerge.tex ]]; then ln -s ../../kOOL_lib/latex/layouts/mailmerge.tex ./mailmerge.tex ; fi
if [[ -L ./tracking.tex ]]; then rm -f ./tracking.tex ; fi
if [[ ! -e ./trackingL.tex ]]; then ln -s ../../kOOL_lib/latex/layouts/trackingL.tex ./trackingL.tex ; fi
if [[ ! -e ./trackingP.tex ]]; then ln -s ../../kOOL_lib/latex/layouts/trackingP.tex ./trackingP.tex ; fi
cd ../../
chgrp $WWW_GROUP latex latex/compile latex/images latex/layouts
chmod g+w latex/compile latex/images



# Module: news
echo -n ", DELETING news"
if [[ -d ./news ]]; then rm -rf news ; fi




# Change group of the whole directory to apache group
chgrp -R $WWW_GROUP .


echo
echo
echo "You can start the web based installation: http://your.kool.server/install"
echo
echo "kOOL setup has finished. Enjoy!"
echo
